@@ -29,7 +29,7 @@ pub fn bind_variables(_sql : &str, arg : &HashMap<String, Value>)  -> String{
 
         let re_key = Regex::new(format!("(?i):{}( |$|\t|\r|\n)", key).as_str()).unwrap();
         let re_key2 = Regex::new(format!("(?i):{}\\)", key).as_str()).unwrap();
-        let re_key3 = Regex::new(format!("(?i):{}\\,", key).as_str()).unwrap();
+        let re_key3 = Regex::new(format!("(?i):{},", key).as_str()).unwrap();
 
         if let Value::String(m) = &value {
             // sql = sql.replace(&format!(":{}", key), &format!("'{}'", m));
